<?php 
/****************************************************
*
* @File: 	theme_functions.php
* @Package:	GetSimple
* @Action:	Functions used by themes. 	
*
*****************************************************/

if (basename($_SERVER['PHP_SELF']) == 'theme_functions.php') { 
	die('You cannot load this page directly.'); 
} 

$thisfile = file_get_contents('data/other/cp_settings.xml');
$datac = simplexml_load_string($thisfile);
$PRETTYURLS = $datac->PRETTYURLS;

//****************************************************//
//** PAGE SPECIFIC FUNCTIONS                        **//
//**                                                **//
//** Functions to display specific page data.       **//
//****************************************************//
	
	function get_page_content() {
		global $content;
		echo stripslashes(html_entity_decode(@$content, ENT_QUOTES, 'UTF-8'));
	}

	function get_page_meta_keywords() {
		global $meta;
		echo stripslashes(html_entity_decode(@$meta, ENT_QUOTES, 'UTF-8'));
	}
	
	function get_page_title() {
		global $title;
		echo stripslashes(html_entity_decode(@$title, ENT_QUOTES));
	}
	
	function get_page_clean_title() {
		global $title;
		echo stripslashes(strip_tags(html_entity_decode(@$title)));
	}
	
	function get_page_slug() {
		global $url;
		echo $url;
	}
	
	function return_page_slug() {
		global $url;
		return $url;
	}
	
	function get_page_date($i = "l, F jS, Y - g:i A") {
		global $date;
		global $TIMEZONE;
		if ($TIMEZONE != '') {
			if (function_exists('date_default_timezone_set')) {
				date_default_timezone_set($TIMEZONE);
			}
		}
		echo date($i, strtotime($date));
	}
	
	function get_page_url() {
		global $url;
		global $SITEURL;
		global $PRETTYURLS;
		global $parent;
		
		if ($PRETTYURLS == '1') {
			if ($url == 'index' ) { $url = ''; } 
			echo $SITEURL . tsl($parent) . $url;
		} else {
			echo $SITEURL .'index.php?id='.$url; 
		}
		
	}


//****************************************************//
//** SITEWIDE FUNCTIONS                             **//
//**                                                **//
//** Functions to display sitewide data.            **//
//****************************************************//

	function get_header() {
		global $url;
		global $SITEURL;
		global $PRETTYURLS;
		global $meta;
		global $title;
		global $content;
		global $parent;
		require_once('configuration.php');
		$description = trim(substr(stripslashes(strip_tags(html_entity_decode(@$content))), 0, 160));
		$description = str_replace('"','', $description);
		$description = str_replace("'",'', $description);
		$description = preg_replace('/\n/', " ", $description);
		$description = preg_replace('/\r/', " ", $description);
		$description = preg_replace('/\t/', " ", $description);
		$description = preg_replace('/ +/', " ", $description);
		$keywords = stripslashes(strip_tags(@$meta));
		echo '<meta name="description" content="'.$description.'" />'."\n";
		echo '	<meta name="keywords" content="'.$keywords.'" />'."\n";
		if ($PRETTYURLS == '1') {
			if ($parent != '') {$parent = $parent."/"; } 
			echo '  <link rel="canonical" href="'.$SITEURL . @$parent . $url .'" />'."\n";
		} else {
			echo '  <link rel="canonical" href="'. $SITEURL .'index.php?id='.$url.'" />'."\n"; 
		}
		echo '	<meta name="generator" content="'. $site_full_name .' - '. $site_version_no .'" />'."\n";
	}
	
	function get_site_url() {
		global $SITEURL;
		echo $SITEURL;
	}
	
	function get_theme_url() {
		global $SITEURL;
		global $TEMPLATE;
		echo $SITEURL . "theme/" . $TEMPLATE;
	}
	
	function get_site_name() {
		global $SITENAME;
		echo stripslashes($SITENAME);
	}

	function get_site_email() {
		global $EMAIL;
		echo stripslashes($EMAIL);
	}
	
	function return_site_ver() {
		include('configuration.php');
		echo $site_version_no;
	}
	
	function get_site_credits() {
		include('configuration.php');
		$site_credit_link = '<a href="'.$site_link_back_url.'">Powered by '.$site_full_name.'</a> Version '. $site_version_no;
		echo stripslashes($site_credit_link);
	}

	function menu_data($id = null) {
		$menu_extract = '';
		global $PRETTYURLS;
		global $SITEURL;
		
		$path = "data/pages";
		$dir_handle = @opendir($path) or die("Unable to open $path");
		$filenames = array();
		while ($filename = readdir($dir_handle)) {
			$filenames[] = $filename;
		}
		
		$count="0";
		$pagesArray = array();
		if (count($filenames) != 0) {
			foreach ($filenames as $file) {
				if ($file == "." || $file == ".." || is_dir("data/pages/".$file) || $file == ".htaccess"  ) {
					// not a page data file
				} else {
					$thisfile = @file_get_contents('data/pages/'.$file);
					$data = simplexml_load_string($thisfile);
					if ($data->private != 'Y') {
						$pagesArray[$count]['menuStatus'] = $data->menuStatus;
						$pagesArray[$count]['menuOrder'] = $data->menuOrder;
						$pagesArray[$count]['menu'] = $data->menu;
						$pagesArray[$count]['parent'] = $data->parent;
						$pagesArray[$count]['title'] = $data->title;
						$pagesArray[$count]['url'] = $data->url;
						$pagesArray[$count]['private'] = $data->private;
						$count++;
					}
				}
			}
		}
		
		$pagesSorted = subval_sort($pagesArray,'menuOrder');
		if (count($pagesSorted) != 0) { 
			$count = 0;
			foreach ($pagesSorted as $page) {
				if ($page['menuStatus'] == 'Y' && $page['private'] != 'Y' ) {
					$text = (string)$page['menu'];
					$pri = (string)$page['menuOrder'];
					$parent = (string)$page['parent'];
					$title = (string)$page['title'];
					$slug = (string)$page['url'];
					
					if ($PRETTYURLS == '1') {
						if ($parent != '') {$parent = $parent."/"; } 
						if ($slug == 'index' ) { $slug = ''; } 
						$url = $SITEURL . @$parent . $slug;
					} else {
						$url = $SITEURL .'index.php?id='.$slug; 
					}
					
					$specific = array("slug"=>$slug,"url"=>$url,"parent_slug"=>$parent,"title"=>$title,"menu_priority"=>$pri,"menu_text"=>$text);
					
					if ($id == $slug) { 
						return $specific; exit; 
					} else {
						$menu_extract[] = $specific;
					}
				}
			}
			return $menu_extract;
		}
		
		closedir($dir_handle);
	}


	function get_component($id) {
		if (file_exists('data/other/components.xml')) {
			$thisfile = file_get_contents("data/other/components.xml");
			$data = simplexml_load_string($thisfile, NULL, LIBXML_NOCDATA);
			$components = $data->item;
			
			if (count($components) != 0) {
				foreach ($components as $component) {
					if ($id == $component->slug) { 
						//echo stripslashes(html_entity_decode($component->value));
						eval("?>" . stripslashes(html_entity_decode($component->value, ENT_QUOTES, 'UTF-8')) . "<?"); 
					}
				}
			}
		}
	}


//****************************************************//
//** FUNCTION: get_navigation()                     **//
//**                                                **//
//** Returns the main menu of the site.             **//
//****************************************************//	
	function get_navigation($currentpage) {
		
		global $PRETTYURLS;
		global $SITEURL;
		$menu = '';

		$path = "data/pages";
		$dir_handle = @opendir($path) or die("Unable to open $path");
		$filenames = array();
		while ($filename = readdir($dir_handle)) {
			$filenames[] = $filename;
		}
		
		$count="0";
		$pagesArray = array();
		if (count($filenames) != 0) {
			foreach ($filenames as $file) {
				if ($file == "." || $file == ".." || is_dir("data/pages/".$file) || $file == ".htaccess"  ) {
					// not a page data file
				} else {
					$thisfile = @file_get_contents('data/pages/'.$file);
					$data = simplexml_load_string($thisfile);
					if ($data->private != 'Y') {
						$pagesArray[$count]['menuStatus'] = $data->menuStatus;
						$pagesArray[$count]['menuOrder'] = $data->menuOrder;
						$pagesArray[$count]['menu'] = $data->menu;
						$pagesArray[$count]['url'] = $data->url;
						$pagesArray[$count]['title'] = $data->title;
						$pagesArray[$count]['parent'] = $data->parent;
						$count++;
					}
				}
			}
		}
		
		$pagesSorted = subval_sort($pagesArray,'menuOrder');
		if (count($pagesSorted) != 0) { 
			foreach ($pagesSorted as $page) {
				$sel = ''; $classes = '';
				$url_nav = $page['url'];
				
				if ($page['menuStatus'] == 'Y') { 
					if ("$currentpage" == "$url_nav") { $classes = "current ". $url_nav; } else { $classes = $url_nav; }
					if ($page['menu'] == '') { $page['menu'] = $page['title']; }
					if ($page['title'] == '') { $page['title'] = $page['menu']; }
					if ($PRETTYURLS == '1') { 
						if ($page['parent'] != '') {$page['parent'] = $page['parent']."/"; }
						if ($url_nav == 'index' ) { $url_nav = ''; }
						$menu .= '<li class="'. $classes .'" ><a href="'. $SITEURL . @$page['parent'] . $url_nav .'" title="'.stripslashes(strip_tags(html_entity_decode($page['title']))).'">'.$page['menu'] .'</a></li>'."\n";
					} else {
						$menu .= '<li class="'. $classes .'" ><a href="'. $SITEURL .'index.php?id='.$url_nav.'" title="'.stripslashes(strip_tags(html_entity_decode($page['title']))).'">'.$page['menu'].'</a></li>'."\n";
					}
				}
			}
			
			echo $menu;
		}
		
		closedir($dir_handle);
	}	


//****************************************************//
//** FUNCTION: set_contact_page()                   **//
//**                                                **//
//** Includes the setup for a contact page.         **//
//****************************************************//
	function set_contact_page() {
		global $EMAIL;
		$style='
			<style>.pot {display:none;}</style>
		';
		echo $style;
		include('contactform.php');
	}

?>